@@ -4,10 +4,6 @@ use regex::Regex;
 use std::collections::HashMap;
 use std::mem;
 
-// Optional wasm-bindgen support
-#[cfg(feature = "wasm")]
-use wasm_bindgen::prelude::*;
-
 // Create a date range using a start and end date
 struct DateRange(NaiveDate, NaiveDate);
 impl Iterator for DateRange {
@@ -23,7 +19,6 @@ impl Iterator for DateRange {
 }
 
 /// Default seed used by ARRIS/CommScope, represents the string "MPSJKMDHAI"
-#[cfg_attr(feature = "wasm", wasm_bindgen)]
 pub static DEFAULT_SEED: &str = "MPSJKMDHAI";
 static TABLE1: [[i32; 5]; 7] = [
     [15, 15, 24, 20, 24],
@@ -167,20 +162,19 @@ fn validate_range(date_begin: &str, date_end: &str) {
 ///
 /// ## Using default seed
 ///
-/// ```
-/// use rspotd::{DEFAULT_SEED, generate}
+/// ```no_run
+/// use rspotd::{DEFAULT_SEED, generate};
 ///
 /// generate("2021-12-25", DEFAULT_SEED);
 /// ```
 ///
 /// ## Using custom seed
 ///
-/// ```
+/// ```no_run
 /// use rspotd::generate;
 ///
 /// generate("2021-12-25", "ABCDEFGH");
 /// ```
-#[cfg_attr(feature = "wasm", wasm_bindgen)]
 pub fn generate(date: &str, seed: &str) -> String {
     validate_date(date);
     let mut owned_seed = seed.to_owned();
@@ -202,20 +196,19 @@ pub fn generate(date: &str, seed: &str) -> String {
 ///
 /// ## Using default seed
 ///
-/// ```
-/// use rspotd::{DEFAULT_SEED, generate_multiple}
+/// ```no_run
+/// use rspotd::{DEFAULT_SEED, generate_multiple};
 ///
 /// generate_multiple("2021-07-23", "2022-07-28", DEFAULT_SEED);
 /// ```
 ///
 /// ## Using custom seed
 ///
-/// ```
+/// ```no_run
 /// use rspotd::generate_multiple;
 ///
 /// generate_multiple("2021-07-23", "2022-07-28", "ABCDABCD");
 /// ```
-#[cfg_attr(feature = "wasm", wasm_bindgen)]
 pub fn generate_multiple(date_begin: &str, date_end: &str, seed: &str) -> HashMap<String, String> {
     validate_date(date_begin);
     validate_date(date_end);
@@ -243,70 +236,4 @@ pub fn generate_multiple(date_begin: &str, date_end: &str, seed: &str) -> HashMa
 }
 
 #[cfg(test)]
-mod tests {
-    use std::collections::HashMap;
-
-    #[test]
-    fn default_seed() {
-        assert_eq!(
-            super::generate("2021-12-25", super::DEFAULT_SEED),
-            "ZCARK8TPK5"
-        );
-    }
-    #[test]
-    fn custom_seed() {
-        assert_eq!(super::generate("2021-12-25", "1122AABB"), "FEWNX8OS0O");
-    }
-    #[test]
-    fn different_date() {
-        assert_eq!(
-            super::generate("1960-10-22", super::DEFAULT_SEED),
-            "WGAR88TPKS"
-        );
-    }
-    #[test]
-    fn small_multiple() {
-        let mut comparison_map: HashMap<String, String> = HashMap::new();
-        let date_begin: String = "2021-12-25".to_string();
-        let date_end: String = "2021-12-26".to_string();
-        let seed_begin: String = "ZCARK8TPK5".to_string();
-        let seed_end: String = "ZOU3MLLZO4".to_string();
-        comparison_map.insert(date_begin, seed_begin);
-        comparison_map.insert(date_end, seed_end);
-        assert_eq!(
-            super::generate_multiple("2021-12-25", "2021-12-26", super::DEFAULT_SEED),
-            comparison_map
-        );
-    }
-    #[test]
-    #[should_panic]
-    fn small_multiple_invalid_range() {
-        println!(
-            "{:?}",
-            super::generate_multiple("2021-12-26", "2021-12-25", super::DEFAULT_SEED)
-        );
-    }
-    #[test]
-    #[should_panic]
-    fn multiple_exceed_year() {
-        println!(
-            "{:?}",
-            super::generate_multiple("2021-12-25", "2022-12-26", super::DEFAULT_SEED)
-        );
-    }
-    #[test]
-    #[should_panic]
-    fn small_seed() {
-        super::generate("1960-10-22", "ABC");
-    }
-    #[test]
-    #[should_panic]
-    fn large_seed() {
-        super::generate("1960-10-22", "ABCABCABC");
-    }
-    #[test]
-    #[should_panic]
-    fn invalid_date() {
-        super::generate("Phoenix dactylifera", super::DEFAULT_SEED);
-    }
-}
+mod tests;
